@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide access to chemical element properties
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0300';
 
 use Moo;
 use strictures 2;
@@ -23,6 +23,15 @@ sub _build_data {
 }
 
 
+has header => (is => 'lazy', init_args => undef);
+
+sub _build_header {
+    my ($self) = @_;
+    my @headers = $self->headers;
+    return \@headers;
+}
+
+
 sub as_file {
     my ($self) = @_;
 
@@ -140,8 +149,7 @@ sub symbol {
 sub value {
     my ($self, $key, $string) = @_;
     my $v;
-    my @headers = $self->headers;
-    my $idx = first_index { $_ =~ /$string/i } @headers;
+    my $idx = first_index { $_ =~ /$string/i } @{ $self->header };
     if ($key !~ /^\d+$/ && length $key < 4) {
         $v = $self->data->{$key}[$idx];
     }
@@ -170,7 +178,7 @@ Chemistry::PeriodicTable - Provide access to chemical element properties
 
 =head1 VERSION
 
-version 0.0202
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -207,6 +215,12 @@ C<Chemistry::PeriodicTable> provides access to chemical element properties.
 
 The computed hash-reference of the element properties.
 
+=head2 header
+
+  $headers = $pt->header;
+
+The computed array-reference of the property headers.
+
 =head1 METHODS
 
 =head2 new
